declare namespace _default {
    /**
     * Sets content size for the given simulator.
     *
     * @since Xcode 15 (but lower xcode could have this command)
     * @param {ContentSizeAction} size - The content size action to set. Acceptable value is
     *                                   extra-small, small, medium, large, extra-large, extra-extra-large,
     *                                   extra-extra-extra-large, accessibility-medium, accessibility-large,
     *                                   accessibility-extra-large, accessibility-extra-extra-large,
     *                                   accessibility-extra-extra-extra-large with Xcode 16.2.
     * @throws {Error} if the current platform does not support content size appearance changes
     * @this {XCUITestDriver}
     */
    function mobileSetContentSize(this: import("../driver").XCUITestDriver, size: ContentSizeAction): Promise<void>;
    /**
     * Retrieves the current content size value from the given simulator.
     *
     * @since Xcode 15 (but lower xcode could have this command)
     * @returns {Promise<ContentSizeResult>} the content size value. Possible return value is
     *                                 extra-small, small, medium, large, extra-large, extra-extra-large,
     *                                 extra-extra-extra-large, accessibility-medium, accessibility-large,
     *                                 accessibility-extra-large, accessibility-extra-extra-large,
     *                                 accessibility-extra-extra-extra-large,
     *                                 unknown or unsupported with Xcode 16.2.
     * @this {XCUITestDriver}
     */
    function mobileGetContentSize(this: import("../driver").XCUITestDriver): Promise<ContentSizeResult>;
}
export default _default;
export type XCUITestDriver = import("../driver").XCUITestDriver;
export type ContentSizeAction = import("./types").ContentSizeAction;
export type ContentSizeResult = import("./types").ContentSizeResult;
//# sourceMappingURL=content-size.d.ts.map