declare namespace _default {
    /**
     * Sets the increase contrast configuration for the given simulator.
     *
     * @since Xcode 15 (but lower xcode could have this command)
     * @param {IncreaseContrastAction} increaseContrast valid increase contrast configuration value.
     *                                                  Acceptable value is 'enabled' or 'disabled' with Xcode 16.2.
     * @throws {Error} if the current platform does not support content size appearance changes
     * @this {XCUITestDriver}
     */
    function mobileSetIncreaseContrast(this: import("../driver").XCUITestDriver, increaseContrast: IncreaseContrastAction): Promise<void>;
    /**
     * Retrieves the current increase contrast configuration value from the given simulator.
     *
     * @since Xcode 15 (but lower xcode could have this command)
     * @returns {Promise<IncreaseContrastResult>} the contrast configuration value.
     *                                      Possible return value is 'enabled', 'disabled',
     *                                      'unsupported' or 'unknown' with Xcode 16.2.
     * @this {XCUITestDriver}
     */
    function mobileGetIncreaseContrast(this: import("../driver").XCUITestDriver): Promise<IncreaseContrastResult>;
}
export default _default;
export type XCUITestDriver = import("../driver").XCUITestDriver;
export type IncreaseContrastAction = import("./types").IncreaseContrastAction;
export type IncreaseContrastResult = import("./types").IncreaseContrastResult;
//# sourceMappingURL=increase-contrast.d.ts.map